#!/usr/bin/env rexx
/*
   author:  Rony G. Flatscher

   date:    2020-09-30

   version: 1.0

   name:    do_the_work.rex

   purpose: - create the batch/shell files named:

              goto_ooRexx{32|64}.{sh|cmd}
              setup_environment4ooRexx{32|64}.{sh|cmd}
              run_ooRexx{32|64}.{sh|cmd}

            - place them into user's home directory ($HOME, %USERPROFILE%)

   restriction:   - currently assumes Intel 32- and 64-bit architectures
                    on Linux and Windows (cf. "bitness2name" variable)

                  - must be placed an run from the "oorexx" directory

   usage:   will be called from create_unix_scripts.sh and create_Windows_scripts.cmd

   license: Common Public License v1.0 (see below)
*/

bDebug=.false

   -- maps bitness (architecture) to directory name
bitness2name=.stringTable~ of( (32,"x86"), (64,"x86_64") )

bitness=.rexxInfo~architecture
fileSep=.rexxInfo~directorySeparator
pathSep=.rexxInfo~pathSeparator

exec   =.rexxInfo~executable              -- full path to rexx[exe]
exec_32=exec~changeStr(bitness2name~64, bitness2name~32)

execPath1=filespec("Path",exec)           -- remove trailing fileSep
execLoc =filespec("location",exec)        -- includes trailing slash
execPath2=execLoc~left(execLoc~length-1)  -- remove trailing fileSep
execPath2_32=execPath2~changeStr(bitness2name~64, bitness2name~32)
drive   =filespec("drive",exec)           -- on Unix: empty string

if bDebug=.true then
do
   say "bitness  :" bitness
   say "fileSep  :" fileSep
   say "pathSep  :" pathSep
   say "exec     :" exec
   say "execLoc  :" execLoc
   say "drive    :" drive
   say "execPath1:" execPath1
   say "execPath2:" execPath2

   do i over bitness2name~allindexes~sort
      say i "->" bitness2name~at(i)
   end
   say
end

parse source opsys +1 . . path
tmpPath=path~left(path~lastPos(fileSep)-1)
lpos=tmpPath~lastPos(fileSep)
scriptSuperDir=tmpPath~substr(lpos+1)

if bDebug=.true then
do
   say "tmpPath="quote(tmpPath)
   say "scriptSuperDir="quote(scriptSuperDir)
end

-- make sure this script is in subdirectory "oorexx"
if scriptSuperDir<>"oorexx" then
do
   say quote(path)": needs to run from subdirectory ""oorexx"", aborting..."
   exit -1
end

env="ENVIRONMENT"    -- address operating system environment
if opsys="W" then    -- Windows
do
   user=value("USERNAME" , , env)
   -- home=value("HOMEDRIVE", , env) || value("HOMEPATH", , env)
   home=value("USERPROFILE", , env)
   batchext = ".cmd"
   hashbang = ""
   comment  = "rem"
   chmod=""

   if bDebug=.true then
   do
      say "user:" user
      say "home:" home
      say

      say "setup_environment:"
      say "PATH="execPath2 || pathSep || "%PATH%"
      say

      say "goto:"
      say "cd" quote(execPath2)
      if drive<>"" then say drive
      say

      say "run:"
      say quote(exec) "%*"
   end
end
else     -- UNIX
do
   user=value("USER" , , env)
   home=value("HOME", , env)
   batchext = ".sh"
   hashbang = "#!/bin/sh"
   comment  = "#"
   chmod="chmod 755"    -- umask

   if bDebug=.true then
   do
      say "user:" user
      say "home:" home
      say

      say "setup_environment:"
      say "export PATH="execPath2 || pathSep || "$PATH"
      say

      say "goto:"
      say "cd" quote(execPath2)
      say

      say "run:"
      say quote(exec) "$*"
   end
end

say "creating scripts for user" quote(user) "storing at:" quote(home)

-- create "goto_ooRexx" scripts
fn=home || fileSep || "goto_ooRexx" || bitness || batchext
command="cd" quote(execPath2)
call createFile fn, command

if opsys<>"D" & bitness=64 then  -- create a 32-bit version as well for Linux and Windows
do
   fn=home || fileSep || "goto_ooRexx" || 32 || batchext
   command="cd" quote(execPath2_32)
   call createFile fn, command
end
if bDebug=.true then say

-- create "setup_environment4ooRexx" scripts
fn=home || fileSep || "setup_environment4ooRexx" || bitness || batchext
if opsys="W" then command=       "PATH="execPath2 || pathSep || "%PATH%"
             else command="export PATH="execPath2 || pathSep || "$PATH"

call createFile fn, command

if opsys<>"D" & bitness=64 then  -- create a 32-bit version as well for Linux and Windows
do
   fn=home || fileSep || "setup_environment4ooRexx" || 32 || batchext
   if opsys="W" then command=       "PATH="execPath2_32 || pathSep || "%PATH%"
                else command="export PATH="execPath2_32 || pathSep || "$PATH"
   call createFile fn, command
end
if bDebug=.true then say

-- create "run_ooRexx" scripts
fn=home || fileSep || "run_ooRexx" || bitness || batchext
if opsys="W" then command=quote(exec) "%*"
             else command=quote(exec) "$*"

call createFile fn, command

if opsys<>"D" & bitness=64 then  -- create a 32-bit version as well for Linux and Windows
do
   fn=home || fileSep || "run_ooRexx" || 32 || batchext
   command=command~changeStr(bitness2name~64, bitness2name~32)
   call createFile fn, command
end
if bDebug=.true then say

exit

createFile:   -- internal routine to access all variables
  use arg fn, command

  say "creating" quote(fn)", command:" quote(command) "..."

  s=.stream~new(fn)~~open("replace")
  if hashbang<>"" then
     s~say(hashbang)
  s~say(comment "created by" user "at" .dateTime~new)
  s~say(command)
  s~close

  if chmod<>"" then     -- on Unix make sure to set executable
     address system chmod fn
  return


::routine quote   -- enquote string
  return '"' || arg(1) || '"'

/*----------------------------------------------------------------------------*/
/*                                                                            */
/* Copyright (c) 2020 Rexx Language Association. All rights reserved.         */
/*                                                                            */
/* This program and the accompanying materials are made available under       */
/* the terms of the Common Public License v1.0 which accompanies this         */
/* distribution. A copy is also available at the following address:           */
/* http://www.oorexx.org/license.html                                         */
/*                                                                            */
/* Redistribution and use in source and binary forms, with or                 */
/* without modification, are permitted provided that the following            */
/* conditions are met:                                                        */
/*                                                                            */
/* Redistributions of source code must retain the above copyright             */
/* notice, this list of conditions and the following disclaimer.              */
/* Redistributions in binary form must reproduce the above copyright          */
/* notice, this list of conditions and the following disclaimer in            */
/* the documentation and/or other materials provided with the distribution.   */
/*                                                                            */
/* Neither the name of Rexx Language Association nor the names                */
/* of its contributors may be used to endorse or promote products             */
/* derived from this software without specific prior written permission.      */
/*                                                                            */
/* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS        */
/* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT          */
/* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS          */
/* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT   */
/* OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,      */
/* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED   */
/* TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,        */
/* OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY     */
/* OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING    */
/* NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS         */
/* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.               */
/*                                                                            */
/*----------------------------------------------------------------------------*/
