/*
   author:  Rony G. Flatscher

   date:    2020-09-30

   version: 1.0

   name:    stickCreateWindows.rex

   purpose: - take the NSIS directory structure for 32- and 64-bit ooRexx and copy
              them to "tmpStick\oorexx\Windows\x86" (32-bit) and
              to "tmpStick\oorexx\Windows\x86_64" (64-bit)
            - assumes the root of the build directory to be in "G:\oorexx.tmp\oorexxBuild",
              the command line can be used to change the root location
            - assumes the subdirectory "debug32.trunk" and "debug64.trunk" to
              be the directories where CMakeCache.txt resid
            - assumes that a NSIS installation package got created

            -> fetches the files from the NSIS\files directory and copy them to the
               "stick" locations:

                     tmpStick\oorexx\Windows\x86[_64]\bin\
                     tmpStick\oorexx\Windows\x86[_64]\include\
                     tmpStick\oorexx\Windows\doc\
                     tmpStick\oorexx\Windows\x86[_64]\samples\

   restriction:   - must be run without cygwin!

   usage:   stickCreateWindows [root-directory-of-oorexx-builds-see-above]

   license: Common Public License v1.0 (see below)

*/

bDebug=.false

parse arg dir
if dir="" then dir="G:\oorexx.tmp\oorexxBuild"

   -- define the locactions (subdirectories) where ooRexx with the NSIS subdirectory
   -- resides, supply bitness indicator directory on stick ("x86": Intel, 32bit;
   -- "x86_64": Intel, 64-bit)
subdirs=.array~of( ("debug32.trunk","x86"), ("debug64.trunk","x86_64"))

if \sysFileExists(dir) then
do
   say pp(dir) "does not exist, aborting ..."
   exit -1
end

baseDir    ="tmpStick"

if sysfileExists(baseDir) then
   address system "rd /s /q" baseDir

stickDir   =baseDir"\oorexx"
address system "mkdir" baseDir
address system "mkdir" stickDir

docDir     =stickDir"\doc\"
includeDir =stickDir"\include\"
nativeDir  =stickDir"\Windows"

do tmpDir over subdirs
   nsisDir    =dir"\"tmpDir[1]"\NSIS\files"
   tmpStickDir=nativeDir"\"tmpDir[2]
   includeDir =nativeDir"\"tmpDir[2]"\include\"

   if bDebug=.true then
   do
      say "nsisDir    ="pp(nsisDir)
      say "tmpStickDir="pp(tmpStickDir)
      say "docDir     ="pp(docDir)
      say "includeDir ="pp(includeDir)
      say "nativeDir  ="pp(nativeDir)
      say "---"
   end

   say "fetching files from" pp(nsisDir) "copying natives to" pp(tmpStickDir)

   address system "md" tmpStickDir       -- recreate directory

   redirect="1>nul 2>nul"
   flags="/s /q"

   address system "xcopy" flags quote(nsisDir"\Core")            quote(tmpStickDir"\bin\") redirect
      -- samples have natives, so keep them under the bitness subtree
   address system "xcopy" flags quote(nsisDir"\Samples\samples") quote(tmpStickDir"\samples\") redirect

      -- common to all operating systems, bitnesses
   flags="/s /q /y"

say "includeDir:" pp(includeDir)
pause

   address system "xcopy" flags quote(nsisDir"\DevLib\api")      quote(includeDir) redirect
   address system "xcopy" flags quote(nsisDir"\Docs\doc")        quote(docDir)     redirect
end

   -- create directory structure for Darwin (MacOS) and Linux stick versions
do str over ("Darwin\x86_64", "Linux\x86_64", "Linux\x86")
    parse var str osname "\"
    tmpDir=stickDir"\"osname
    if \sysFileExists(tmpDir) then
       address system "md" tmpDir

    address system "md" stickDir"\"str
end

::routine pp
  return "["arg(1)"]"

::routine quote
  return '"'arg(1)'"'

/*----------------------------------------------------------------------------*/
/*                                                                            */
/* Copyright (c) 2020 Rexx Language Association. All rights reserved.         */
/*                                                                            */
/* This program and the accompanying materials are made available under       */
/* the terms of the Common Public License v1.0 which accompanies this         */
/* distribution. A copy is also available at the following address:           */
/* http://www.oorexx.org/license.html                                         */
/*                                                                            */
/* Redistribution and use in source and binary forms, with or                 */
/* without modification, are permitted provided that the following            */
/* conditions are met:                                                        */
/*                                                                            */
/* Redistributions of source code must retain the above copyright             */
/* notice, this list of conditions and the following disclaimer.              */
/* Redistributions in binary form must reproduce the above copyright          */
/* notice, this list of conditions and the following disclaimer in            */
/* the documentation and/or other materials provided with the distribution.   */
/*                                                                            */
/* Neither the name of Rexx Language Association nor the names                */
/* of its contributors may be used to endorse or promote products             */
/* derived from this software without specific prior written permission.      */
/*                                                                            */
/* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS        */
/* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT          */
/* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS          */
/* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT   */
/* OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,      */
/* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED   */
/* TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,        */
/* OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY     */
/* OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING    */
/* NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS         */
/* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.               */
/*                                                                            */
/*----------------------------------------------------------------------------*/
